==> Java-Swing-0.02.tar.gz: Java-Swing-0.02/java/PerlListDataListener.java <==
import javax.swing.event.ListDataListener;
import org.perl.inline.java.*;

public class      PerlListDataListener
       extends    InlineJavaPerlCaller
       implements ListDataListener
{
    String sender;
    String callbacks;

    public PerlListDataListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void intervalAdded(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing::ListDataListener",
                "_ListDataListener",
                new Object[] {sender, callbacks, "intervalAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void intervalRemoved(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing::ListDataListener",
                "_ListDataListener",
                new Object[] {sender, callbacks, "intervalRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void contentsChanged(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing::ListDataListener",
                "_ListDataListener",
                new Object[] {sender, callbacks, "contentsChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlListDataListener.java <==
import javax.swing.event.ListDataListener;
import org.perl.inline.java.*;

public class      PerlListDataListener
       extends    InlineJavaPerlCaller
       implements ListDataListener
{
    String sender;
    String callbacks;

    public PerlListDataListener() throws InlineJavaException { }

    public PerlListDataListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void intervalAdded(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "intervalAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void intervalRemoved(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "intervalRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void contentsChanged(javax.swing.event.ListDataEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "contentsChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
